# setting working directory and In/Outputfolders
wdir <- "C:/Users/lenovo/Desktop/R_scripts/Test"
setwd(wdir)
inputFolder <- paste( wdir, "/my_new_inputfiles/", sep = "" )
outputFolder <- paste( wdir, "/my_new_outputfiles/", sep = "" )

# Libraries and functions
library("gplots")
library("sciplot")
library("coin")
library("lattice")
library("corrgram")
source(paste( wdir, "/R_functions/maPalette.r", sep = "" ))
source(paste( wdir, "/R_functions/tern_e.R", sep = "" ))
source(paste( wdir, "/R_functions/vennDia.R", sep = "" ))
source(paste( wdir, "/R_functions/error.bar.R", sep = "" ))
source(paste( wdir, "/R_functions/BayesianIUT/R/BayesianIUT", sep = "" ))
source(paste( wdir, "/R_functions/panel.shade.ks.R", sep = "" ))
source(paste( wdir, "/R_functions/panel.conf.ks.R", sep = "" ))


#############################################################
#############################################################
#############################################################
#
# Dataanalysis of greenhouse experiments: ACM
# L28 - greenhouse rep1  ==> GM
# L35 - greenhouse rep2  ==> NonGM
# L35 - greenhouse rep3  ==> CK
#
#############################################################
#############################################################
#############################################################


### uploading of design file
#############################################################
designfile <- "Dataset_S1.txt"
alldesign <- read.table( paste( inputFolder, designfile, sep = "" ), header=T)
rownames(alldesign) <- alldesign[,1]
Group <- paste(alldesign$Species, alldesign$Type, sep="_")
Group2 <- paste(alldesign$Species, alldesign$Genotype, sep="_")
SiteGroup <- paste(alldesign$Rep, alldesign$Species, sep="_")
alldesign <- cbind(alldesign, Group, Group2, SiteGroup)
alldesign[1:5,]


### subsets by libraries 
# greenhouse exp1 (L28) ==> GM
Ghrep1_samples <- rownames(alldesign)[which(alldesign$Lib == "GM")]
Ghrep1_design <- droplevels(alldesign[Ghrep1_samples,])

# greenhouse exp2 (L35)==> NonGM
Ghrep2_samples <- rownames(alldesign)[which(alldesign$Lib == "NonGM")]
Ghrep2_design <- droplevels(alldesign[Ghrep2_samples,])

# greenhouse exp2 (L35)==> CK
Ghrep3_samples <- rownames(alldesign)[which(alldesign$Lib == "CK")]
Ghrep3_design <- droplevels(alldesign[Ghrep3_samples,])

GH_design <- rbind(Ghrep1_design, Ghrep2_design, Ghrep3_design)


### upload of rarefied OTU table from  
#############################################################
datafile <- "ACM.OTU.10.txt"
alldat <- read.table( paste( inputFolder, datafile, sep = "" ), row.names=1, sep="\t", header=T, blank.lines.skip = FALSE)
dim(alldat)
colnames(alldat)
rownames(alldat)[1:10]


## ordering the count data
dat_rare <- alldat[,c(Ghrep1_samples, Ghrep2_samples, Ghrep3_samples)]
colnames(dat_rare)
dim(dat_rare)
sort(colSums(dat_rare), decr=T)


## uploading taxonomy assignments
GGtax <- alldat[,71:77]
dim(GGtax)
colnames(GGtax)
GGtax[1:5,]
table(GGtax[, 1])
GGtax_20 <- GGtax


## Data transformation and thresholding
dat_norm_20 <- t(t(dat_rare)/colSums(dat_rare)) * 1000
dat_log_20 <- log2(dat_norm_20 + 1)


GMSamples <- rownames(GH_design)[which(GH_design$Species == "GM")]
NonGMSamples <- rownames(GH_design)[which(GH_design$Species == "NonGM")]
CKSamples <- rownames(GH_design)[which(GH_design$Species == "CK")]

dat_log_GM <- dat_log_20[, GMSamples]
dat_log_GM_mean <- sort(apply(dat_log_GM, 1, mean), dec=T)  # ordered decreasing by rank abundance
dat_log_NonGM <- dat_log_20[, NonGMSamples]
dat_log_NonGM_mean <- sort(apply(dat_log_NonGM, 1, mean), dec=T)
dat_log_CK <- dat_log_20[, CKSamples]
dat_log_CK_mean <- sort(apply(dat_log_CK, 1, mean), dec=T)  

y.means.mat <- matrix(c(dat_log_GM_mean, dat_log_NonGM_mean, dat_log_CK_mean), 3, 168, byrow=TRUE)
colnames(y.means.mat) <- names(dat_log_GM_mean)
rownames(y.means.mat) <- c("GM", "NonGM", "CK")
y.means.allOTUs <- t(y.means.mat)

#############################################################
# plotting communities
# by 3D rank abundance bargraphs (3D)
#############################################################
# ACM OTUs
means.allOTUs <- apply(y.means.allOTUs, 1, mean)
allOTUs.order <- names(sort(means.allOTUs, decr=T))
y.means.allOTUs_mean <- y.means.allOTUs[allOTUs.order,]       # sorted by mean abundance (all species)
## 3D plots
postscript(paste(outputFolder,"Fig4A_3DRA_allOTUs_meanorder.eps", sep=""), paper="special", width=8, height=8, horizontal = FALSE)
cols <- maPalette(l="black",m="yellow",h="orange")
wireframe(y.means.allOTUs_mean, drape=TRUE, cuts=6,
          aspect=c(38/50, 0.5),
          xlab="CQM OTUs", ylab="Species", zlab="RA log2", zlim=c(0,8),
          screen=list(x=-55,y=-25, z=-17),
          col.regions=cols, at=seq(0,8,8/50),
          par.settings=list(box.3d=list(col=c(1,NA,NA,1 ,1,NA,1,1, 1), lwd=1, cex=2)),
          # par.settings=list(box.umbrella=list(lty=1)),
          lwd=1)
dev.off()

