
# setting working directory and In/Outputfolders
wdir <- "C:/Users/lenovo/Desktop/R_scripts/Test"
setwd(wdir)
inputFolder <- paste( wdir, "/my_new_inputfiles/", sep = "" )
outputFolder <- paste( wdir, "/my_new_outputfiles/", sep = "" )

# Libraries and functions
library("gplots")
library("sciplot")
library("coin")
library("grid") 
source(paste( wdir, "/R_functions/tern_e.R", sep = "" ))
source(paste( wdir, "/R_functions/vennDia.R", sep = "" ))
source(paste( wdir, "/R_functions/error.bar.R", sep = "" ))
source(paste( wdir, "/R_functions/BayesianIUT/R/BayesianIUT", sep = "" ))   

datafile <- "Dataset_S3.ACM.txt"
alldat <- read.table( paste( inputFolder, datafile, sep = "" ), row.names=1, sep="\t", header=T, blank.lines.skip = FALSE)

designfile <- "Dataset_S1.txt"
alldesign <- read.table( paste( inputFolder, designfile, sep = "" ), header=T)
rownames(alldesign) <- alldesign[,1]
Group <- paste(alldesign$Species, alldesign$Type, sep="_")
Group2 <- paste(alldesign$Species, alldesign$Genotype, sep="_")
SiteGroup <- paste(alldesign$Rep, alldesign$Species, sep="_")
alldesign <- cbind(alldesign, Group, Group2, SiteGroup)

#samples <- rownames(alldesign)[which(alldesign$Library_ID == "L39")]
samples <- rownames(alldesign)
#Cologne_samples <- rownames(alldesign)[which(alldesign$Library_ID == "L388")]

#design <- droplevels(alldesign[samples,])
design <- alldesign

#dat_rare <- alldat[,c(Cologne_samples, samples)]
dat_rare <- alldat[,samples]

dat_norm_20 <- t(t(dat_rare)/colSums(dat_rare)) * 1000

dat_log_20 <- log2(dat_norm_20 + 1)

#dat_log_20 <- dat_log_20[,samples]
dat_log_20 <- dat_log_20

GGtax <- alldat[,71:77]
GGtax_20 <- GGtax
OTU_tax <- paste("OTU", rownames(GGtax_20), GGtax_20$Family, sep="_")
names(OTU_tax) <- rownames(GGtax_20)
GGtax_20 <- cbind(GGtax_20, OTU_tax)

#########################################
#GMsamples ==> GM
#NonGMsamples ==> NonGM
#CKsamples ==> CK
#########################################

GMsamples <- rownames(design)[which(design$Group == "GM_GM")]
NonGMsamples <- rownames(design)[which(design$Group == "NonGM_NonGM")]
CKsamples <- rownames(design)[which(design$Group == "CK_CK")]

## mean of the OTUs(rows=1,colums=2,both=1:2)
means_log_NonGM <- apply(dat_log_20[, NonGMsamples], 1, mean)
means_log_GM <- apply(dat_log_20[, GMsamples], 1, mean)
means_log_CK <- apply(dat_log_20[, CKsamples], 1, mean)

se_log_NonGM <- apply(dat_log_20[, NonGMsamples], 1, se)
se_log_GM <- apply(dat_log_20[, GMsamples], 1, se)
se_log_CK <- apply(dat_log_20[, CKsamples], 1, se)

# stats matrix
# using ANOVA(TukeyHSD) to return P values, BH method to correct P values
OTU_pmat <- as.data.frame(t(apply(dat_log_20 ,1 ,function(x){ design$OTU_freq <- x;
                            pvals=TukeyHSD( aov(OTU_freq ~ Group, data=design), which="Group")$Group[,4]
}))) 
OTU_pmat <- apply(OTU_pmat, 2, function(x){p.adjust(x,"BH")})

# parallel: fold change matrix
OTU_folds <- as.data.frame(t(apply(dat_log_20 ,1 ,function(x){ design$OTU_freq <- x;
                            folds=TukeyHSD( aov(OTU_freq ~ Group, data=design), which="Group")$Group[,1]
})))


### retrieving GMOTUs 
#GMOTUs <- rownames(OTU_pmat)[which(OTU_pmat[,c("GM_GM-CK_CK","NonGM_NonGM-CK_CK","NonGM_NonGM-GM_GM")] < 0.1)]
#GMOTUs <- GMOTUs[GMOTUs %in% rownames(OTU_folds)[which(OTU_folds[,c("GM_GM-CK_CK","NonGM_NonGM-CK_CK","NonGM_NonGM-GM_GM")] > 0)]]
GMOTUs <- rownames(OTU_pmat)[which(OTU_pmat[,"NonGM_NonGM-GM_GM"] < 0.1)]
GMOTUs <- GMOTUs[GMOTUs %in% rownames(OTU_folds)[which(OTU_pmat[,"NonGM_NonGM-GM_GM"] > 0)]]

GMOTUs <- unique(GMOTUs)

# meansmats per plot
means_log_ALL <- cbind(means_log_GM, means_log_NonGM, means_log_CK)
colnames(means_log_ALL) <- c("GM","NonGM","CK")
means_log_ALL[means_log_ALL == 0] <- 0.0000001

se_log_ALL <- cbind(se_log_GM, se_log_NonGM, se_log_CK)
colnames(se_log_ALL) <- c("GM_se","NonGM_se","CK_se")

### general colorcode for taxonomy labels
dim(GGtax_20)
names(sort(table(droplevels(GGtax_20[,"Phylum"])),decr=T))
PHYLAcols <- as.character(GGtax_20[,"Phylum"])
names(PHYLAcols) <- rownames(GGtax_20)
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Proteobacteria"]] <- "seagreen4"     # "palegreen4" #"chartreuse4" "springgreen4" #
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Firmicutes"]] <- "indianred3"    #"tomato2"# "deeppink3"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Actinobacteria"]] <- "steelblue2"     #"cornflowerblue" # blue4
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Acidobacteria"]] <- "tan1"              #"darkorange2"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Chlorobi"]] <- "seagreen3"                #"tomato2"# "deeppink3"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Gemmatimonadetes"]] <- "gold1"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Nitrospirae"]] <- "brown"
PHYLAcols[PHYLAcols == ""] <- "tomato2"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Chloroflexi"]] <- "dimgrey"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Cyanobacteria"]] <- "mediumpurple3"    # "mediumorchid4"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "GN04"]] <- "mediumorchid4"

PHYLAcols_legend <- names(sort(table(PHYLAcols), dec=T))
names(PHYLAcols_legend) <- names(sort(table(droplevels(GGtax_20[,"Phylum"])), decr=T))
names(PHYLAcols_legend)[PHYLAcols_legend == "gold1"] <- "Gemmatimonadetes"
names(PHYLAcols_legend)[PHYLAcols_legend == "seagreen3"] <- "Chlorobi"
names(PHYLAcols_legend)[names(PHYLAcols_legend) == ""] <- "not_assigned"
PHYLAcols_legend

#tiff(paste(outputFolder,"PHYLAcols_color_legend_bubbles.tiff", sep=""), width=800, height=800, 
#    units="px", pointsize=10, compression="none", bg = "white", res=120 , type="quartz", antialias="none")
plot(y=seq(1,11,1),x=rep(1,11), ylim=c(0,12), col=PHYLAcols_legend, pch=19, cex=5, main="color code Phyla")
text(y=seq(1,11,1),x=rep(1,11), labels=names(PHYLAcols_legend), pos=4, cex=1)
#dev.off()


### At GMOTUs
#The function droplevels is used to drop unused levels from a factor or, more commonly, from factors in a data frame.
table(droplevels(GGtax_20[GMOTUs, 2]))
means_log_ALL <- means_log_ALL[c(rownames(means_log_ALL)[!rownames(means_log_ALL) %in% GMOTUs], GMOTUs),]
se_log_ALL <- se_log_ALL[c(rownames(se_log_ALL)[!rownames(se_log_ALL) %in% GMOTUs], GMOTUs),]

GMOTUs_colors <- PHYLAcols[rownames(means_log_ALL)]
GMOTUs_colors[names(GMOTUs_colors)[!names(GMOTUs_colors) %in% GMOTUs]] <- "grey"
#postscript(paste(outputFolder,"FigS9B_Atdata_GMOTUs.eps", sep=""), paper="special", width=5, height=5, horizontal = FALSE)
postscript(paste(outputFolder,"3treatmen.ternary.eps", sep=""), paper="special", width=5, height=5, horizontal = FALSE)
tern_e(means_log_ALL, col=GMOTUs_colors, prop=T, grid=T,  bg="transparent", pch=19, main="Atdata_GMOTUs")
dev.off()

#write different OTU to file
GMOTUs <- t(GMOTUs)
output_tax <- GGtax_20[GMOTUs, ]
output_tax.sta <- table(droplevels(GGtax_20[GMOTUs, 2]))
log_ALL <- cbind(means_log_ALL, se_log_ALL)
log_ALL <- log_ALL[GMOTUs,]
OTU_pmat <- OTU_pmat[GMOTUs,]
OTU_folds <- OTU_folds[GMOTUs,]

outputFile <- paste(outputFolder,"GM2NonGM.variable.OTUs.info", sep="")

write.table(GMOTUs, file = outputFile, 
		append = F, quote = FALSE, sep = " ",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = FALSE, qmethod = c("escape", "double"),
            fileEncoding = "")

write.table(output_tax.sta, file = outputFile, 
		append = TRUE, quote = F, sep = " ",
            eol = "\n", na = "NA", dec = ".", row.names = F,
            col.names = T, qmethod = c("escape", "double"),
            fileEncoding = "")

write.table(output_tax, file = outputFile, 
		append = TRUE, quote = F, sep = " ",
            eol = "\n", na = "NA", dec = ".", row.names = T,
            col.names = T, qmethod = c("escape", "double"),
            fileEncoding = "")

write.table(log_ALL, file = outputFile, 
		append = TRUE, quote = F, sep = " ",
            eol = "\n", na = "NA", dec = ".", row.names = T,
            col.names = T, qmethod = c("escape", "double"),
            fileEncoding = "")

write.table(OTU_pmat, file = outputFile, 
		append = TRUE, quote = F, sep = " ",
            eol = "\n", na = "NA", dec = ".", row.names = T,
            col.names = T, qmethod = c("escape", "double"),
            fileEncoding = "")

write.table(OTU_folds, file = outputFile, 
		append = TRUE, quote = F, sep = " ",
            eol = "\n", na = "NA", dec = ".", row.names = T,
            col.names = T, qmethod = c("escape", "double"),
            fileEncoding = "")


