
# setting working directory and In/Outputfolders
wdir <- "C:/Users/lenovo/Desktop/R_scripts/Test"
setwd(wdir)
inputFolder <- paste( wdir, "/my_new_inputfiles/", sep = "" )
outputFolder <- paste( wdir, "/my_new_outputfiles/", sep = "" )

# Libraries and functions
library("gplots")
library("sciplot")
library("coin")
library("grid") 
#library("affy")
#library("limma")
source(paste( wdir, "/R_functions/tern_e.R", sep = "" ))
source(paste( wdir, "/R_functions/vennDia.R", sep = "" ))
source(paste( wdir, "/R_functions/error.bar.R", sep = "" ))
source(paste( wdir, "/R_functions/BayesianIUT/R/BayesianIUT", sep = "" ))   

datafile <- "ACM.OTU.10.txt"
alldat <- read.table( paste( inputFolder, datafile, sep = "" ), row.names=1, sep="\t", header=T, blank.lines.skip = FALSE)

designfile <- "MA.Dataset_S1.txt"
alldesign <- read.table( paste( inputFolder, designfile, sep = "" ), header=T)
rownames(alldesign) <- alldesign[,1]
Group <- paste(alldesign$Species, alldesign$Type, sep="_")
Group2 <- paste(alldesign$Species, alldesign$Genotype, sep="_")
SiteGroup <- paste(alldesign$Rep, alldesign$Species, sep="_")
alldesign <- cbind(alldesign, Group, Group2, SiteGroup)

#########################################
# Eifel ==> StageIV
# Cologne ==> StageV
# AtRoot ==> GM
# Chroot ==> NonGM
#########################################

Eifel_samples <- rownames(alldesign)[which(alldesign$Library_ID == "StageIV")]
Cologne_samples <- rownames(alldesign)[which(alldesign$Library_ID == "StageV")]

Eifel_design <- droplevels(alldesign[Eifel_samples,])
Cologne_design <- droplevels(alldesign[Cologne_samples,])

dat_rare <- alldat[,c(Cologne_samples, Eifel_samples)]
dat_norm_20 <- t(t(dat_rare)/colSums(dat_rare)) * 1000
dat_log_20 <- log2(dat_norm_20 + 1)

dat_log_ns_Eifel <- dat_log_20[,Eifel_samples]
dat_log_ns_Cologne <- dat_log_20[,Cologne_samples]

GGtax <- alldat[,71:77]
GGtax_20 <- GGtax
OTU_tax <- paste("OTU", rownames(GGtax_20), GGtax_20$Family, sep="_")
names(OTU_tax) <- rownames(GGtax_20)
GGtax_20 <- cbind(GGtax_20, OTU_tax)

#########################################
# Eifel ==> StageIV
# Cologne ==> StageV
# AtRoot ==> GM
# Chroot ==> NonGM
#Eifel_AtRootsamples ==> StageIV_GM
#Eifel_AtRhizosamples ==> StageIV_NonGM
#Cologne_AtRootsamples ==> StageV_GM
#Cologne_AtRhizosamples ==> StageV_NonGM
#Eifel_SOILsamples ==> StageIV_CK
#Eifel_means_log_Atroot[1:10]
#Cologne_means_log_Atroot[1:10]
#Eifel_means_log_Chroot[1:10]
#Cologne_means_log_Chroot[1:10]
#########################################

Eifel_AtRootsamples <- rownames(Eifel_design)[which(Eifel_design$Group == "GM_GM")]
Eifel_Chrootsamples <- rownames(Eifel_design)[which(Eifel_design$Group == "NonGM_NonGM")]
Cologne_AtRootsamples <- rownames(Cologne_design)[which(Cologne_design$Group == "GM_GM")]
Cologne_Chrootsamples <- rownames(Cologne_design)[which(Cologne_design$Group == "NonGM_NonGM")]

## mean of the OTUs(rows=1,colums=2,both=1:2)
Eifel_means_log_Chroot <- apply(dat_log_20[, Eifel_Chrootsamples], 1, mean)
Eifel_means_log_Atroot <- apply(dat_log_20[, Eifel_AtRootsamples], 1, mean)
Cologne_means_log_Chroot <- apply(dat_log_20[, Cologne_Chrootsamples], 1, mean)
Cologne_means_log_Atroot <- apply(dat_log_20[, Cologne_AtRootsamples], 1, mean)


# stats matrix
# using ANOVA(TukeyHSD) to return P values, BH method to correct P values
Eifel_OTU_pmat <- as.data.frame(t(apply(dat_log_ns_Eifel ,1 ,function(x){ Eifel_design$OTU_freq <- x;
                            pvals=TukeyHSD( aov(OTU_freq ~ Group, data=Eifel_design), which="Group")$Group[,4]
}))) 
Eifel_OTU_pmat <- apply(Eifel_OTU_pmat, 2, function(x){p.adjust(x,"BH")})

Cologne_OTU_pmat <- as.data.frame(t(apply(dat_log_ns_Cologne ,1 ,function(x){ Cologne_design$OTU_freq <- x;
                            pvals=TukeyHSD( aov(OTU_freq ~ Group, data=Cologne_design), which="Group")$Group[,4]
}))) 
Cologne_OTU_pmat <- apply(Cologne_OTU_pmat, 2, function(x){p.adjust(x,"BH")})

# parallel: fold change matrix
Eifel_OTU_folds <- as.data.frame(t(apply(dat_log_ns_Eifel ,1 ,function(x){ Eifel_design$OTU_freq <- x;
                            folds=TukeyHSD( aov(OTU_freq ~ Group, data=Eifel_design), which="Group")$Group[,1]
})))
Cologne_OTU_folds <- as.data.frame(t(apply(dat_log_ns_Cologne ,1 ,function(x){ Cologne_design$OTU_freq <- x;
                            folds=TukeyHSD( aov(OTU_freq ~ Group, data=Cologne_design), which="Group")$Group[,1]
})))

### retrieving RootOTUs 
#Eifel_AtRootOTUs <- rownames(Eifel_OTU_pmat)[which(Eifel_OTU_pmat[,c("GM_GM-CK_CK","NonGM_NonGM-CK_CK","NonGM_NonGM-GM_GM")] < 0.1)]
#Eifel_AtRootOTUs <- Eifel_AtRootOTUs[Eifel_AtRootOTUs %in% rownames(Eifel_OTU_folds)[which(Eifel_OTU_folds[,c("GM_GM-CK_CK","NonGM_NonGM-CK_CK","NonGM_NonGM-GM_GM")] > 0)]]

Eifel_AtRootOTUs <- rownames(Eifel_OTU_pmat)[which(Eifel_OTU_pmat[,"NonGM_NonGM-GM_GM"] < 0.1)]
Eifel_AtRootOTUs <- Eifel_AtRootOTUs[Eifel_AtRootOTUs %in% rownames(Eifel_OTU_folds)[which(Eifel_OTU_pmat[,"NonGM_NonGM-GM_GM"] > 0)]]
Eifel_RootOTUs <- unique(Eifel_AtRootOTUs)

Cologne_ChrootOTUs <- rownames(Cologne_OTU_pmat)[which(Cologne_OTU_pmat[,"NonGM_NonGM-GM_GM"] < 0.1)]
Cologne_ChrootOTUs <- Cologne_ChrootOTUs[Cologne_ChrootOTUs %in% rownames(Cologne_OTU_folds)[which(Cologne_OTU_pmat[,"NonGM_NonGM-GM_GM"] > 0)]]
Cologne_RootOTUs <- unique(Cologne_ChrootOTUs)

# meansmats per plot
#Eifel_means_log_At <- cbind(Eifel_means_log_Atroot, Eifel_means_log_Atrhizo, Eifel_means_log_soil)
#colnames(Eifel_means_log_At) <- c("GM","NonGM","CK")
#Eifel_means_log_At[Eifel_means_log_At == 0] <- 0.0000001

### general colorcode for taxonomy labels
dim(GGtax_20)
names(sort(table(droplevels(GGtax_20[,"Phylum"])),decr=T))
PHYLAcols <- as.character(GGtax_20[,"Phylum"])
names(PHYLAcols) <- rownames(GGtax_20)
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Proteobacteria"]] <- "seagreen4"     # "palegreen4" #"chartreuse4" "springgreen4" #
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Firmicutes"]] <- "indianred3"    #"tomato2"# "deeppink3"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Actinobacteria"]] <- "steelblue2"     #"cornflowerblue" # blue4
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Acidobacteria"]] <- "tan1"              #"darkorange2"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Chlorobi"]] <- "seagreen3"                #"tomato2"# "deeppink3"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Gemmatimonadetes"]] <- "gold1"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Nitrospirae"]] <- "brown"
PHYLAcols[PHYLAcols == ""] <- "tomato2"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Chloroflexi"]] <- "dimgrey"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "Cyanobacteria"]] <- "mediumpurple3"    # "mediumorchid4"
PHYLAcols[names(PHYLAcols)[PHYLAcols == "GN04"]] <- "mediumorchid4"

PHYLAcols_legend <- names(sort(table(PHYLAcols), dec=T))
names(PHYLAcols_legend) <- names(sort(table(droplevels(GGtax_20[,"Phylum"])), decr=T))
names(PHYLAcols_legend)[PHYLAcols_legend == "gold1"] <- "Gemmatimonadetes"
names(PHYLAcols_legend)[PHYLAcols_legend == "seagreen3"] <- "Chlorobi"
names(PHYLAcols_legend)[names(PHYLAcols_legend) == ""] <- "not_assigned"
PHYLAcols_legend

#tiff(paste(outputFolder,"PHYLAcols_color_legend_bubbles.tiff", sep=""), width=800, height=800, 
#    units="px", pointsize=10, compression="none", bg = "white", res=120 , type="quartz", antialias="none")
plot(y=seq(1,11,1),x=rep(1,11), ylim=c(0,12), col=PHYLAcols_legend, pch=19, cex=5, main="color code Phyla")
text(y=seq(1,11,1),x=rep(1,11), labels=names(PHYLAcols_legend), pos=4, cex=1)
#dev.off()

#############################################################
# plotting At and Ch RootOTUs in communities 
# by MA plots (MA)
#############################################################
#?ma.plot # library("affy")
#?plotMA  # library("limma")

### 2x MA plot
# M = log(S1/S2) = log(S1) - log(S2)           # log fold change on y-axis
# A = 0.5*log(S1*S2) = 0.5*(log(S1) + log(S2)) # average log abundance (A) on x-axis
# data
Eifel_means_log_Atroot[1:10]
Cologne_means_log_Atroot[1:10]
Eifel_means_log_Chroot[1:10]
Cologne_means_log_Chroot[1:10]
average_A <- apply(cbind(Eifel_means_log_Atroot,Cologne_means_log_Atroot,Eifel_means_log_Chroot,Cologne_means_log_Chroot),1,mean)
species <- 0.5*(Eifel_means_log_Atroot+Cologne_means_log_Atroot) - 0.5*(Eifel_means_log_Chroot+Cologne_means_log_Chroot)
site <- 0.5*(Eifel_means_log_Atroot+Eifel_means_log_Chroot) - 0.5*(Cologne_means_log_Atroot+Cologne_means_log_Chroot)

# RootOTUs of both sites
RootOTUs_ns_aov <- unique(c(Eifel_RootOTUs, Cologne_RootOTUs))
RootOTUs_ns_aov
length(RootOTUs_ns_aov)
table(droplevels(GGtax_20[RootOTUs_ns_aov,"Phylum"]))

# plotting RootOTUs by Phyla colors                                                          
postscript(paste(outputFolder,"siteSpecies_StageIV_StageV-NonGM_NonGM-GM_GM_MAplot_phylum.eps", sep=""), paper="special", width=5, height=5, horizontal = FALSE)
par(mar=c(5,5,5,5))
plot(x=species, y=site, xlim=c(-6.5,6.5), ylim=c(-6.5,6.5), col="grey", bg = "transparent", pch=19, bty="n")
points(x=species[RootOTUs_ns_aov], y=site[RootOTUs_ns_aov], pch=19, col=PHYLAcols[RootOTUs_ns_aov])
dev.off()

Eifel_AtRootOTUs <- rownames(Eifel_OTU_pmat)[which(Eifel_OTU_pmat[,"NonGM_NonGM-CK_CK"] < 0.1)]
Eifel_AtRootOTUs <- Eifel_AtRootOTUs[Eifel_AtRootOTUs %in% rownames(Eifel_OTU_folds)[which(Eifel_OTU_pmat[,"NonGM_NonGM-CK_CK"] > 0)]]
Eifel_RootOTUs <- unique(Eifel_AtRootOTUs)

Cologne_ChrootOTUs <- rownames(Cologne_OTU_pmat)[which(Cologne_OTU_pmat[,"NonGM_NonGM-CK_CK"] < 0.1)]
Cologne_ChrootOTUs <- Cologne_ChrootOTUs[Cologne_ChrootOTUs %in% rownames(Cologne_OTU_folds)[which(Cologne_OTU_pmat[,"NonGM_NonGM-CK_CK"] > 0)]]
Cologne_RootOTUs <- unique(Cologne_ChrootOTUs)

### 2x MA plot
# M = log(S1/S2) = log(S1) - log(S2)           # log fold change on y-axis
# A = 0.5*log(S1*S2) = 0.5*(log(S1) + log(S2)) # average log abundance (A) on x-axis
# data
Eifel_means_log_Atroot[1:10]
Cologne_means_log_Atroot[1:10]
Eifel_means_log_Chroot[1:10]
Cologne_means_log_Chroot[1:10]
average_A <- apply(cbind(Eifel_means_log_Atroot,Cologne_means_log_Atroot,Eifel_means_log_Chroot,Cologne_means_log_Chroot),1,mean)
species <- 0.5*(Eifel_means_log_Atroot+Cologne_means_log_Atroot) - 0.5*(Eifel_means_log_Chroot+Cologne_means_log_Chroot)
site <- 0.5*(Eifel_means_log_Atroot+Eifel_means_log_Chroot) - 0.5*(Cologne_means_log_Atroot+Cologne_means_log_Chroot)

# RootOTUs of both sites
RootOTUs_ns_aov <- unique(c(Eifel_RootOTUs, Cologne_RootOTUs))
RootOTUs_ns_aov
length(RootOTUs_ns_aov)
table(droplevels(GGtax_20[RootOTUs_ns_aov,"Phylum"]))

# plotting RootOTUs by Phyla colors                                                          
postscript(paste(outputFolder,"siteSpecies_StageIV_StageV-NonGM_NonGM-CK_CK_MAplot_phylum.eps", sep=""), paper="special", width=5, height=5, horizontal = FALSE)
par(mar=c(5,5,5,5))
plot(x=species, y=site, xlim=c(-6.5,6.5), ylim=c(-6.5,6.5), col="grey", bg = "transparent", pch=19, bty="n")
points(x=species[RootOTUs_ns_aov], y=site[RootOTUs_ns_aov], pch=19, col=PHYLAcols[RootOTUs_ns_aov])
dev.off()

Eifel_AtRootOTUs <- rownames(Eifel_OTU_pmat)[which(Eifel_OTU_pmat[,"GM_GM-CK_CK"] < 0.1)]
Eifel_AtRootOTUs <- Eifel_AtRootOTUs[Eifel_AtRootOTUs %in% rownames(Eifel_OTU_folds)[which(Eifel_OTU_pmat[,"GM_GM-CK_CK"] > 0)]]
Eifel_RootOTUs <- unique(Eifel_AtRootOTUs)

Cologne_ChrootOTUs <- rownames(Cologne_OTU_pmat)[which(Cologne_OTU_pmat[,"GM_GM-CK_CK"] < 0.1)]
Cologne_ChrootOTUs <- Cologne_ChrootOTUs[Cologne_ChrootOTUs %in% rownames(Cologne_OTU_folds)[which(Cologne_OTU_pmat[,"GM_GM-CK_CK"] > 0)]]
Cologne_RootOTUs <- unique(Cologne_ChrootOTUs)

### 2x MA plot
# M = log(S1/S2) = log(S1) - log(S2)           # log fold change on y-axis
# A = 0.5*log(S1*S2) = 0.5*(log(S1) + log(S2)) # average log abundance (A) on x-axis
# data
Eifel_means_log_Atroot[1:10]
Cologne_means_log_Atroot[1:10]
Eifel_means_log_Chroot[1:10]
Cologne_means_log_Chroot[1:10]
average_A <- apply(cbind(Eifel_means_log_Atroot,Cologne_means_log_Atroot,Eifel_means_log_Chroot,Cologne_means_log_Chroot),1,mean)
species <- 0.5*(Eifel_means_log_Atroot+Cologne_means_log_Atroot) - 0.5*(Eifel_means_log_Chroot+Cologne_means_log_Chroot)
site <- 0.5*(Eifel_means_log_Atroot+Eifel_means_log_Chroot) - 0.5*(Cologne_means_log_Atroot+Cologne_means_log_Chroot)

# RootOTUs of both sites
RootOTUs_ns_aov <- unique(c(Eifel_RootOTUs, Cologne_RootOTUs))
RootOTUs_ns_aov
length(RootOTUs_ns_aov)
table(droplevels(GGtax_20[RootOTUs_ns_aov,"Phylum"]))

# plotting RootOTUs by Phyla colors                                                          
postscript(paste(outputFolder,"siteSpecies_StageIV_StageV-GM_GM-CK_CK_MAplot_phylum.eps", sep=""), paper="special", width=5, height=5, horizontal = FALSE)
par(mar=c(5,5,5,5))
plot(x=species, y=site, xlim=c(-6.5,6.5), ylim=c(-6.5,6.5), col="grey", bg = "transparent", pch=19, bty="n")
points(x=species[RootOTUs_ns_aov], y=site[RootOTUs_ns_aov], pch=19, col=PHYLAcols[RootOTUs_ns_aov])
dev.off()
