
rm(list = ls())

# cpcoa_fun.R contains the functions used for handling the CCA objects 
# generated by the vegan package function capscale as well as for plotting 
# samples and species scores and performing the ANOVA-based permutation tests

source("C:/Users/lenovo/Desktop/R_scripts/Figure_4B_5B_CAP_analysis/new_cpcoa_fun.R")

inputFolder <- "C:/Users/lenovo/Desktop/R_scripts/Figure_4B_5B_CAP_analysis/stages_my_inputfiles/"
outputFolder <- "C:/Users/lenovo/Desktop/R_scripts/Figure_4B_5B_CAP_analysis/stages_my_outputfiles/"

designfile <- "NonGMdesign.txt"
datafile <- "NonGM_data_normalized.txt"
taxfile <- "ACM_supplementary_data_taxonomy.txt"

# load design matrix and subset by experiment
design <- read.table( paste( inputFolder, designfile, sep = "" ), header=T)
rownames(design) <- design[,1]

# load OTU abundance matrix
NonGMdat <- read.table(paste(inputFolder, datafile, sep = ""), 
                     row.names = 1, sep="\t", header = T, blank.lines.skip = F)
dat <- NonGMdat

# load OTU taxonomic information
RDPtax_20 <- read.table( paste( inputFolder, taxfile, sep = "" ),
	blank.lines.skip=F,header=T)
	
rownames(RDPtax_20) <- RDPtax_20[,1]
d <- data.frame(Compartment = design$Type, Rep = design$Rep, 
                Species = design$Species, Experiment = design$Exp)
rownames(d) <- rownames(design)
dat_core <- t(as.matrix(dat))
t_transformed_core <- tr(dat_core)


######### NonGM_ALL
# load subsets of OTUs obtained with the ANOVA-based analysis
coreRootOTUs <- read.table(paste(inputFolder, "NonGM_OTUs.txt", sep = ""))
coreRootOTUs <- as.character(coreRootOTUs[, 1])
dat_RootOTUs_core <- t_transformed_core[, coreRootOTUs]

# perform the CAP analysis using the capscale function within the vegan package
sqrt_transform = F
capscale.gen_core <- capscale(dat_RootOTUs_core ~ Species, 
                              data = d, add = F, 
                              sqrt.dis = sqrt_transform)

# perform the ANOVA-based permutation tests for each transformation
perm_anova.gen_core <- anova.cca(capscale.gen_core)

# generate variance tables
var_tbl.gen_core <- variability_table(capscale.gen_core)
cap_var.gen_core <- cap_var_props(capscale.gen_core)

# calculate confidence intervals for the variance of each constrained transf.
ci.gen_core <-  cca_ci(capscale.gen_core)

# obtain the coordinates of the samples for each transformation (sample scores)
wa.gen_core <- capscale.gen_core$CCA$wa[, 1:2]

# obtain the coordinates of the OTUs for each transformation (species scores)
v.gen_core <- capscale.gen_core$CCA$v[, 1:2]

# get the centroids of the constrained factors (spp.)
centroids.gen_core <- capscale.gen_core$CCA$centroids[, 1:2]

# plot the different CPCoA transformations
plot_cap(p = wa.gen_core, d = d, col_var = c("StageI", "StageII", "StageIII", "StageIV","StageV"), 
         pch_var = c("StageI", "StageII", "StageIII", "StageIV","StageV"), 
         col_comp = c("Species", "Species", "Species", "Species", "Species"), 
         pch_comp = c("Species", "Species", "Species", "Species", "Species"), 
     	 shapes = c(8:12), 
         colors = c("red", "green", "blue", "purple", "black"), 
         file_name = paste(outputFolder, "NonGM_ALL_ACM_PCoA_samples.StageI2V.eps", sep = ""),
         svg = F, constraint = "Species", ci = ci.gen_core,
     	 var_tbl = var_tbl.gen_core, cap_var = cap_var.gen_core,
         perm_anova = perm_anova.gen_core, cex.main = 0.8, cex = 1)


# plot biplots and species scores
plot_biplots(p = v.gen_core, centroids = centroids.gen_core, pch=1, col="black",
             file_name = paste(outputFolder, "NonGM_ALL_ACM_PCoA_phylum.StageI2V.eps", sep=""), 
             svg = F, constraint="Repetition", ci = ci.gen_core, 
             var_tbl = var_tbl.gen_core, cap_var = cap_var.gen_core, 
             perm_anova = perm_anova.gen_core, abundances = t_transformed_core, 
             otu_subset = coreRootOTUs, taxonomy = RDPtax_20, cex.main = 0.8, cex = 0.7)

write.table(centroids.gen_core, file = paste(outputFolder,"NonGM_ALL_ACM_PCoA.centroids.phylum.txt"), sep="\t")

######### NonGM_Shared
# load subsets of OTUs obtained with the ANOVA-based analysis
coreRootOTUs <- read.table(paste(inputFolder, "Shared.NonGM_OTUs.txt", sep = ""))
coreRootOTUs <- as.character(coreRootOTUs[, 1])
dat_RootOTUs_core <- t_transformed_core[, coreRootOTUs]

# perform the CAP analysis using the capscale function within the vegan package
sqrt_transform = F
capscale.gen_core <- capscale(dat_RootOTUs_core ~ Species, 
                              data = d, add = F, 
                              sqrt.dis = sqrt_transform)

# perform the ANOVA-based permutation tests for each transformation
perm_anova.gen_core <- anova.cca(capscale.gen_core)

# generate variance tables
var_tbl.gen_core <- variability_table(capscale.gen_core)
cap_var.gen_core <- cap_var_props(capscale.gen_core)

# calculate confidence intervals for the variance of each constrained transf.
ci.gen_core <-  cca_ci(capscale.gen_core)

# obtain the coordinates of the samples for each transformation (sample scores)
wa.gen_core <- capscale.gen_core$CCA$wa[, 1:2]

# obtain the coordinates of the OTUs for each transformation (species scores)
v.gen_core <- capscale.gen_core$CCA$v[, 1:2]

# get the centroids of the constrained factors (spp.)
centroids.gen_core <- capscale.gen_core$CCA$centroids[, 1:2]

# plot the different CPCoA transformations
plot_cap(p = wa.gen_core, d = d, col_var = c("StageI", "StageII", "StageIII", "StageIV","StageV"), 
         pch_var = c("StageI", "StageII", "StageIII", "StageIV","StageV"), 
         col_comp = c("Species", "Species", "Species", "Species", "Species"), 
         pch_comp = c("Species", "Species", "Species", "Species", "Species"), 
     	 shapes = c(8:12), 
         colors = c("red", "green", "blue", "purple", "black"), 
         file_name = paste(outputFolder, "NonGM_Shared_ACM_PCoA_samples.StageI2V.eps", sep = ""),
         svg = F, constraint = "Species", ci = ci.gen_core,
     	 var_tbl = var_tbl.gen_core, cap_var = cap_var.gen_core,
         perm_anova = perm_anova.gen_core, cex.main = 0.8, cex = 1)


# plot biplots and species scores
plot_biplots(p = v.gen_core, centroids = centroids.gen_core, pch=1, col="black",
             file_name = paste(outputFolder, "NonGM_Shared_ACM_PCoA_phylum.StageI2V.eps", sep=""), 
             svg = F, constraint="Repetition", ci = ci.gen_core, 
             var_tbl = var_tbl.gen_core, cap_var = cap_var.gen_core, 
             perm_anova = perm_anova.gen_core, abundances = t_transformed_core, 
             otu_subset = coreRootOTUs, taxonomy = RDPtax_20, cex.main = 0.8, cex = 0.7)

write.table(centroids.gen_core, file = paste(outputFolder,"NonGM_Shared_ACM_PCoA.centroids.phylum.txt"), sep="\t")

######### NonGM_Diff
# load subsets of OTUs obtained with the ANOVA-based analysis
coreRootOTUs <- read.table(paste(inputFolder, "Diff.NonGM_OTUs.txt", sep = ""))
coreRootOTUs <- as.character(coreRootOTUs[, 1])
dat_RootOTUs_core <- t_transformed_core[, coreRootOTUs]

# perform the CAP analysis using the capscale function within the vegan package
sqrt_transform = F
capscale.gen_core <- capscale(dat_RootOTUs_core ~ Species, 
                              data = d, add = F, 
                              sqrt.dis = sqrt_transform)

# perform the ANOVA-based permutation tests for each transformation
perm_anova.gen_core <- anova.cca(capscale.gen_core)

# generate variance tables
var_tbl.gen_core <- variability_table(capscale.gen_core)
cap_var.gen_core <- cap_var_props(capscale.gen_core)

# calculate confidence intervals for the variance of each constrained transf.
ci.gen_core <-  cca_ci(capscale.gen_core)

# obtain the coordinates of the samples for each transformation (sample scores)
wa.gen_core <- capscale.gen_core$CCA$wa[, 1:2]

# obtain the coordinates of the OTUs for each transformation (species scores)
v.gen_core <- capscale.gen_core$CCA$v[, 1:2]

# get the centroids of the constrained factors (spp.)
centroids.gen_core <- capscale.gen_core$CCA$centroids[, 1:2]

# plot the different CPCoA transformations
plot_cap(p = wa.gen_core, d = d, col_var = c("StageI", "StageII", "StageIII", "StageIV","StageV"), 
         pch_var = c("StageI", "StageII", "StageIII", "StageIV","StageV"), 
         col_comp = c("Species", "Species", "Species", "Species", "Species"), 
         pch_comp = c("Species", "Species", "Species", "Species", "Species"), 
     	 shapes = c(8:12), 
         colors = c("red", "green", "blue", "purple", "black"), 
         file_name = paste(outputFolder, "NonGM_Diff_ACM_PCoA_samples.StageI2V.eps", sep = ""),
         svg = F, constraint = "Species", ci = ci.gen_core,
     	 var_tbl = var_tbl.gen_core, cap_var = cap_var.gen_core,
         perm_anova = perm_anova.gen_core, cex.main = 0.8, cex = 1)


# plot biplots and species scores
plot_biplots(p = v.gen_core, centroids = centroids.gen_core, pch=1, col="black",
             file_name = paste(outputFolder, "NonGM_Diff_ACM_PCoA_phylum.StageI2V.eps", sep=""), 
             svg = F, constraint="Repetition", ci = ci.gen_core, 
             var_tbl = var_tbl.gen_core, cap_var = cap_var.gen_core, 
             perm_anova = perm_anova.gen_core, abundances = t_transformed_core, 
             otu_subset = coreRootOTUs, taxonomy = RDPtax_20, cex.main = 0.8, cex = 0.7)

write.table(centroids.gen_core, file = paste(outputFolder,"NonGM_Diff_ACM_PCoA.centroids.phylum.txt"), sep="\t")

